@@ -62,7 +62,7 @@ usage() {
     echo ""
 }
 
-NVIDIA_BUG_REPORT_CHANGE='$Change: 34685233 $'
+NVIDIA_BUG_REPORT_CHANGE='$Change: 35030023 $'
 NVIDIA_BUG_REPORT_VERSION=`echo "$NVIDIA_BUG_REPORT_CHANGE" | tr -c -d "[:digit:]"`
 
 # Set the default filename so that it won't be empty in the usage message
@@ -1307,25 +1307,23 @@ dump_mlx() {
     # mlxlink --amber_collect file will dump information to the specified csv file, and
     # print information to stdout (in color).
     # Capture both and remove the color escape characters.
-    for port in $(seq 1 5); do
-        echo "$1 -d $2 -p $port --amber_collect $MLX_CSV > $MLX_INFO 2>&1"
-        "$1" -d "$2" -p $port --amber_collect "$MLX_CSV" > "$MLX_INFO" 2>&1
-        if [ $? -eq 0 ]; then
-            cat "$MLX_INFO" | sed -Ee 's/\x1b\[[0-9;]+m//g' 2> /dev/null
-            cat "$MLX_CSV" 2> /dev/null
-            echo "____________________________________________"
-            echo ""
-            rm -f "$MLX_INFO" 2> /dev/null
-            rm -f "$MLX_CSV" 2> /dev/null
-            break
-        else
-            echo "failed with error $? retrying..."
-            cat "$MLX_INFO" | sed -Ee 's/\x1b\[[0-9;]+m//g' 2> /dev/null
-            rm -f "$MLX_INFO" 2> /dev/null
-            rm -f "$MLX_CSV" 2> /dev/null
-            echo "____________________________________________"
-        fi
-    done
+    echo "$1 -d $2 --amber_collect $MLX_CSV > $MLX_INFO 2>&1"
+    "$1" -d "$2" --amber_collect "$MLX_CSV" > "$MLX_INFO" 2>&1
+    if [ $? -eq 0 ]; then
+        cat "$MLX_INFO" | sed -Ee 's/\x1b\[[0-9;]+m//g' 2> /dev/null
+        cat "$MLX_CSV" 2> /dev/null
+        echo "____________________________________________"
+        echo ""
+        rm -f "$MLX_INFO" 2> /dev/null
+        rm -f "$MLX_CSV" 2> /dev/null
+        break
+    else
+        echo "failed with error $? retrying..."
+        cat "$MLX_INFO" | sed -Ee 's/\x1b\[[0-9;]+m//g' 2> /dev/null
+        rm -f "$MLX_INFO" 2> /dev/null
+        rm -f "$MLX_CSV" 2> /dev/null
+        echo "____________________________________________"
+    fi
 }
 
 (
@@ -1355,6 +1353,7 @@ dump_mlx() {
 
             resourcedump=`which resourcedump 2> /dev/null | head -n 1`
             mstdump=`which mstdump 2> /dev/null | head -n 1`
+            mlxreg=`which mlxreg 2> /dev/null | head -n 1`
 
             # dumps all the scanned devices
             report_command "$mst status -v"
@@ -1368,35 +1367,54 @@ dump_mlx() {
                 do
                 echo $tmp_line | grep "netir" > /dev/null  2>&1
                 if [ $? -eq 0 ]; then
-                    echo "Starting GPU MST dump..."$tmp_line
                     devName=`echo $tmp_line | awk -F" " 'NR == 1 {print $1}';`
-                    dump_mlx "$mlxlink" "$devName"
-                    if [ ! -z "$resourcedump" ]; then
-                        report_command "$resourcedump dump -d $devName -s 0x5025"
+                    if [ ! -z "$devName" ]; then
+                        echo "Starting GPU MST dump..."$tmp_line
                         echo "____________________________________________"
-                        echo ""
+                        dump_mlx "$mlxlink" "$devName"
+                        if [ ! -z "$resourcedump" ]; then
+                            report_command "$resourcedump dump -d $devName -s 0x5024"
+                            echo "____________________________________________"
+                            echo ""
+                        fi
                     fi
                 fi
                 echo $tmp_line | grep "Quantum" | grep "mlx5_0" > /dev/null 2>&1
                 if [ $? -eq 0 ]; then
-                    echo "Starting Quantum dump..."$tmp_line
                     devName=`echo $tmp_line | awk -F" " 'NR == 1 {print $1}';`
-                    dump_mlx "$mlxlink" "$devName"
-                    if [ ! -z "$resourcedump" ]; then
-                        report_command "$resourcedump dump -d $devName -s 0x5025"
+                    if [ ! -z "$devName" ]; then
+                        echo "Starting Quantum dump..."$tmp_line
                         echo "____________________________________________"
-                        echo ""
+                        dump_mlx "$mlxlink" "$devName"
+                        if [ ! -z "$resourcedump" ]; then
+                            report_command "$resourcedump dump -d $devName -s 0x5024"
+                            echo "____________________________________________"
+                            echo "Starting Quantum flash dump..."
+                            echo "____________________________________________"
+                            report_command "$resourcedump dump -d $devName -s 0x5028"
+                            echo "____________________________________________"
+                            if [ ! -z "$mlxreg" ]; then
+                                echo "Clearing Quantum flash dump..."
+                                echo "____________________________________________"
+                                report_command "$mlxreg -d $devName --set erase_log=0x1 --reg_name MOFDE -y"
+                                echo "____________________________________________"
+                            fi
+                            echo ""
+                        fi
                     fi
                 fi
-                echo $tmp_line | grep "ConnectX" | grep "pciconf0.[2,3]" > /dev/null 2>&1
+                echo $tmp_line | grep "ConnectX" > /dev/null 2>&1
                 if [ $? -eq 0 ]; then
-                    echo "Starting ConnectX dump..."$tmp_line
-                    devName=`echo $tmp_line | awk -F" " 'NR == 1 {print $2}';`
-                    dump_mlx "$mlxlink" "$devName"
-                    if [ ! -z "$mstdump" ]; then
-                        report_command "$mstdump $devName"
+                    devName=`echo $tmp_line | awk -F" " 'NR == 1 {print $3}';`
+                    if [ ! -z "$devName" ]; then
+                        echo "Starting ConnectX dump..."$tmp_line
                         echo "____________________________________________"
-                        echo ""
+                        dump_mlx "$mlxlink" "$devName"
+                        if [ ! -z "$mstdump" ]; then
+                            report_command "$mstdump $devName"
+                            echo "____________________________________________"
+                            echo ""
+                        fi
                     fi
                 fi
                 done
